@@ -1,5 +1,5 @@
 import platform,os,sys
-
+from pathlib import Path
 
 def main() :
 
@@ -12,7 +12,6 @@ def main() :
         sys.exit(1)
 
     if platform.system() == 'Windows':
-        os.system("audit_pkg\dist\main.exe %s %s" % (client_id,client_secret))
+        os.system(str(Path(__file__).resolve().parent)+"\dist\main.exe %s %s" % (client_id,client_secret))
     else :
-        os.system("./audit_pkg/dist/main %s %s" % (client_id,client_secret))
-main()
\ No newline at end of file
+        os.system(str(Path(__file__).resolve().parent)+"/dist/main %s %s" % (client_id,client_secret))
